/*
 * 
 * The Seasar Software License, Version 1.1
 *
 * Copyright (c) 2003-2004 The Seasar Project. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or 
 * without modification, are permitted provided that the following 
 * conditions are met:
 *
 * 1. Redistributions of source code must retain the above 
 *    copyright notice, this list of conditions and the following 
 *    disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above 
 *    copyright notice, this list of conditions and the following 
 *    disclaimer in the documentation and/or other materials provided 
 *    with the distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgement:  
 *    "This product includes software developed by the 
 *    Seasar Project (http://www.seasar.org/)."
 *    Alternately, this acknowledgement may appear in the software
 *    itself, if and wherever such third-party acknowledgements 
 *    normally appear.
 *
 * 4. Neither the name "The Seasar Project" nor the names of its
 *    contributors may be used to endour or promote products derived 
 *    from this software without specific prior written permission of 
 *    the Seasar Project.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR 
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE SEASAR PROJECT 
 * OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL,SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS 
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING 
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.seasar.kijimuna.core.rtti;

import org.eclipse.jdt.core.Flags;
import org.eclipse.jdt.core.IMethod;
import org.eclipse.jdt.core.JavaModelException;

/**
 * @author Masataka Kurihara (Gluegent, Inc.)
 */
class DefaultRttiMethod implements IRttiMethod {

	private IRtti parent;
	private IRtti[] args;
	private String methodName;
	private IRtti returnType;
	private boolean fFinal;
	private boolean fStatic;
	private IRtti[] values;
	
	DefaultRttiMethod(IRtti parent,
	        IMethod method, String methodName, IRtti[] args, IRtti returnType) {
		this.parent = parent;
		this.methodName = methodName;
		this.args = args;
		this.returnType = returnType;
	    try {
	        int flag = method.getFlags();
	        fFinal = Flags.isFinal(flag);
	        fStatic = Flags.isStatic(flag);
        } catch (JavaModelException e) {
        }
	}
	
	public IRtti getParent() {
		return parent;
	}

	public IRtti[] getArgs() {
		return args;
	}

	public String getMethodName() {
		return methodName;
	}

	public IRtti getReturnType() {
		return returnType;
	}
	
	public boolean isFinal() {
	    return fFinal;
	}
	
	public boolean isStatic() {
	    return fStatic;
	}
	
    public int compareTo(Object test) {
        if(test instanceof IRttiMethod) {
            IRttiMethod testMethod = (IRttiMethod)test;
            return getMethodName().compareTo(testMethod.getMethodName());
        } else {
            return 0;
        }
    }
    
    
	public IRtti[] getValues() {
		return values;
	}

	public void setValues(IRtti[] values) {
		this.values = values;
	}
}
